/*
 * feedbackd
 *
 * Copyright (c) 2016 - 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <stdio.h>
#include <fcntl.h>
#include <sys/reboot.h>
#include <glib.h>

#include "core/log.h"
#include "core/common.h"
#include "core/dbus.h"
#include "haptic/haptic.h"

static GMainLoop *mainloop = NULL;

static void sig_quit(int signo)
{
	_D("received SIGTERM signal %d", signo);
}

static void sig_usr1(int signo)
{
	_D("received SIGUSR1 signal %d, feedbackd'll be finished!", signo);

	if (mainloop) {
		if (g_main_loop_is_running(mainloop))
			g_main_loop_quit(mainloop);
		mainloop = NULL;
	}
}

int main(int argc, char **argv)
{
	int ret;

	mainloop = g_main_loop_new(NULL, FALSE);

	if (!dbus_handle_init(G_BUS_TYPE_SYSTEM, VIBRATOR_BUS_NAME)) {
		_E("failed to init dbus connection");
	}

	ret = haptic_probe();
	if (ret != 0) {
		_E("[haptic] probe fail");
		return ret;
	}
	haptic_init();

	signal(SIGTERM, sig_quit);
	signal(SIGUSR1, sig_usr1);

	/* g_main_loop */
	g_main_loop_run(mainloop);

	_D("[haptic] deinitialize");
	haptic_exit();
	g_main_loop_unref(mainloop);
	mainloop = NULL;

	return 0;
}
